**Example 1: 删除参数模板**

删除参数模板

Input: 

```
tccli cynosdb DeleteParamTemplate --cli-unfold-argument  \
    --TemplateId 93
```

Output: 
```
{
    "Response": {
        "RequestId": "855d70ae-2815-4311-a42e-75a41ee0af8b"
    }
}
```

